package compbio.ws.jpred;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;

/**
 * Jpred interface of the corresponding web serice in ProteoCache
 * 
 * @author Alexander Sherstnev
 * @author Natasha Sherstneva
 * 
 * @version 1.0
 * @since Jan 2014
 */
@WebService(targetNamespace = "http://server.proteocache.ws")
public interface Jpred {

	/**
	 * Returns a number of jobs xecuted for a protein with a program of a
	 * version
	 * 
	 * @param sequence
	 *            the protein sequence
	 * @param program
	 *            the program title
	 * @param version
	 *            the program version
	 * @return a number of jobs executed for the protein
	 */
	@WebMethod
	public int findSequence(@WebParam(name = "sequence") String sequence, @WebParam(name = "program") String program,
			@WebParam(name = "version") String version);

	/**
	 * Returns a job ID executed for a protein with a program of a version if
	 * the job archive file is available, otherwise returns empty string
	 * 
	 * @param sequence
	 *            the protein sequence
	 * @param program
	 *            the program title
	 * @param version
	 *            the program version
	 * @return job ID
	 */
	@WebMethod
	public String findJobForSequence(@WebParam(name = "sequence") String sequence, @WebParam(name = "program") String program,
			@WebParam(name = "version") String version);

	/**
	 * Returns a relative web link to the job archive file for a ProteoCache
	 * job, if the file is not available null is returned
	 * 
	 * @param jobid
	 *            the job ID
	 * @return the job archive file web link or null
	 */
	@WebMethod
	public String getArchive(@WebParam(name = "job") String jobid);

	/**
	 * Checks whether a job with a given Job ID is kept in ProteoCache
	 * 
	 * @param jobid
	 *            the job ID
	 * @return 1 if the job exists, 0 - otherwise
	 */
	@WebMethod
	public int jobExists(@WebParam(name = "job") String jobid);
}
